@@ -5,6 +5,7 @@ from merlin.wizards.utils import Step
 from merlin.wizards.session import SessionWizard
 
 from merlin.tests.fixtures.testproject import forms
+from merlin.tests.fixtures.testproject import views
 
 urlpatterns = patterns('',
     url(r'^simpletest$', SessionWizard([
@@ -16,4 +17,6 @@ urlpatterns = patterns('',
     url(r'^bettertest/(?P<slug>[A-Za-z0-9_-]+)$', MockWizard([
         Step('user-details', forms.UserDetailsForm),
         Step('contact-details', forms.ContactDetailsForm)])),
+    url(r'^$', views.index, name='test-index'),
+    url(r'^more$', views.more, name='test-more'),
 )
